@@ -60,6 +60,8 @@ def test_gtiff2array():
     assert (
         abs(canopy_box.mean().values.item() - expected) < SMALL
         and abs(canopy.mean().values.item() - expected) < SMALL
+        and isinstance(canopy.attrs["scales"], tuple)
+        and isinstance(canopy.attrs["offsets"], tuple)
     )
 
 
